@@ -31,3 +31,15 @@ class FileAdapter:
 
     def save_json(self, data: dict, **kwargs: Any) -> None:
         filesystem.write_json_file(self.file_path, data, **kwargs)
+
+    async def async_read(self) -> str:
+        return await filesystem.async_read_file(self.file_path)
+
+    async def async_save(self, data: str = "") -> None:
+        await filesystem.async_write_file(self.file_path, data)
+
+    async def async_read_json(self, **kwargs: Any) -> dict:
+        return await filesystem.async_read_json_file(self.file_path, **kwargs)
+
+    async def async_save_json(self, data: dict, **kwargs: Any) -> None:
+        await filesystem.async_write_json_file(self.file_path, data, **kwargs)
